Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1068)

Unified Diff: remoting/protocol/me2me_host_authenticator_factory.h

Issue 1755273003: Simplify AuthenticationMethod type and PIN hash handling. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/protocol/me2me_host_authenticator_factory.h
diff --git a/remoting/protocol/me2me_host_authenticator_factory.h b/remoting/protocol/me2me_host_authenticator_factory.h
index 5cc1beed5e75dc49b53ca6492d2079d849c77b88..18ad8d37b4ad0c3605fc7bc91484f02f64a5b551 100644
--- a/remoting/protocol/me2me_host_authenticator_factory.h
+++ b/remoting/protocol/me2me_host_authenticator_factory.h
@@ -27,13 +27,13 @@ class PairingRegistry;
class Me2MeHostAuthenticatorFactory : public AuthenticatorFactory {
public:
// Create a factory that dispenses shared secret authenticators.
- static scoped_ptr<AuthenticatorFactory> CreateWithSharedSecret(
+ static scoped_ptr<AuthenticatorFactory> CreateWithPin(
bool use_service_account,
const std::string& host_owner,
const std::string& local_cert,
scoped_refptr<RsaKeyPair> key_pair,
const std::string& required_client_domain,
- const SharedSecretHash& shared_secret_hash,
+ const std::string& pin_hash,
scoped_refptr<PairingRegistry> pairing_registry);
// Create a factory that dispenses third party authenticators.
@@ -62,8 +62,8 @@ class Me2MeHostAuthenticatorFactory : public AuthenticatorFactory {
scoped_refptr<RsaKeyPair> key_pair_;
std::string required_client_domain_;
- // Used only for shared secret host authenticators.
- SharedSecretHash shared_secret_hash_;
+ // Used only for PIN-based host authenticators.
+ std::string pin_hash_;
// Used only for third party host authenticators.
scoped_ptr<TokenValidatorFactory> token_validator_factory_;

Powered by Google App Engine
This is Rietveld 408576698